<?php

declare(strict_types=1);

/*
 * This file is part of the 'octris/validate' package.
 *
 * (c) Harald Lapp <harald@octris.org>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Octris\Validate;

/**
 * Superclass for validators.
 *
 * @copyright   copyright (c) 2010-present by Harald Lapp
 * @author      Harald Lapp <harald@octris.org>
 */
abstract class AbstractValidator
{
    /**
     * Stores validator options.
     *
     * @type    array
     */
    protected array $options = [];

    /**
     * Constructor.
     *
     * @param   array       $options        Optional options for validator.
     */
    public function __construct(array $options = [])
    {
        $this->options = $options;
    }

    /**
     * Validator implementation.
     *
     * @param   mixed       $value          Value to validate.
     * @return  bool                        Returns true if value is valid.
     * @abstract
     */
    abstract public function validate(mixed $value): bool;

    /**
     * Filter values for unwanted characters before validating them.
     *
     * @param   mixed       $value          Value to filter.
     * @return  mixed                       Filtered value.
     */
    public function preFilter(mixed $value): mixed
    {
        // replace nullbytes
        $value = str_replace("\0", '', $value);

        return $value;
    }

    /**
     * Return validator options.
     *
     * @return  array                       Validator options.
     */
    protected function getOptions(): array
    {
        return $this->options;
    }
}
